# Scoped Concerns Py

Scoped Concerns Py is the Python version of the Ruby's [Scope-Concerns](https://github.com/threefunkymonkeys/scoped-concerns) gem. It is a tiny utility library to help you encapsulate responsibilities in your Python applications by providing a common interface and a common response object for the so called service classes or how we like to call them: concerns.

We've been playing around with this concept in a few applications and it was evolving until this point that we feel it reusable enough to become a separated library.

# Install

It is a ruby 
